@@ -14,12 +14,12 @@
 # # limitations under the License.
 
 
-from quickshow.reduce_dim import vis_pca, vis_tsne2d, vis_tsne3d
+from quickshow.reduce_dim import vis_pca, vis_tsne2d, vis_tsne3d, joint_pca2d, joint_tsne2d
 from quickshow.cluster import vis_cluster_plot
 from quickshow.eval_clf_model import vis_cm, get_total_cr_df, vis_multi_plot
 from quickshow.utils import find_all_files
 
 __all__ = ["vis_tsne2d", "vis_tsne3d", "vis_pca", "vis_cluster_plot", "vis_cm"
-           ,"get_total_cr_df", "vis_multi_plot", "find_all_files", "rcparams"]
+           ,"get_total_cr_df", "vis_multi_plot", "find_all_files", "rcparams", "joint_pca2d", "joint_tsne2d"]
 
-__version__ = "0.1.11"
\ No newline at end of file
+__version__ = "0.1.13"
\ No newline at end of file
